@@ -486,7 +486,7 @@ void SPVM_DUMPER_dump_my(SPVM_COMPILER* compiler, SPVM_MY* my) {
     else if (SPVM_TYPE_is_ref_type(compiler, type->basic_type->id, type->dimension, type->flag)) {
       printf("ref");
     }
-    else if (SPVM_TYPE_is_value_type(compiler, type->basic_type->id, type->dimension, type->flag)) {
+    else if (SPVM_TYPE_is_multi_numeric_type(compiler, type->basic_type->id, type->dimension, type->flag)) {
       SPVM_PACKAGE* value_package =  type->basic_type->package;
       
       SPVM_FIELD* first_field = SPVM_LIST_fetch(value_package->fields, 0);
