@@ -425,7 +425,8 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "RETURN_VALUE_FLOAT",
   "RETURN_VALUE_DOUBLE",
   "SET_CROAK_FLAG_TRUE",
-  "CROAK",
+  "DIE",
+  "WARN",
   "REF",
   "REF_BYTE",
   "REF_SHORT",
