@@ -19,7 +19,7 @@ int32_t SPNATIVE__SPVM__CORE__strtoi(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (!obj_string) {
     SPVM_DIE("String must be defined", MFILE, __LINE__);
   }
-  const char* string = (const char*)env->belems(env, obj_string);
+  const char* string = (const char*)env->get_elems_byte(env, obj_string);
   
   int32_t digit = stack[1].ival;
   
@@ -48,7 +48,7 @@ int32_t SPNATIVE__SPVM__CORE__strtol(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (!obj_string) {
     SPVM_DIE("String must be defined", MFILE, __LINE__);
   }
-  const char* string = (const char*)env->belems(env, obj_string);
+  const char* string = (const char*)env->get_elems_byte(env, obj_string);
   
   int32_t digit = stack[1].ival;
 
@@ -77,7 +77,7 @@ int32_t SPNATIVE__SPVM__CORE__strtof(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (!obj_string) {
     SPVM_DIE("String must be defined", MFILE, __LINE__);
   }
-  const char* string = (const char*)env->belems(env, obj_string);
+  const char* string = (const char*)env->get_elems_byte(env, obj_string);
   
   char *end;
   errno = 0;
@@ -100,7 +100,7 @@ int32_t SPNATIVE__SPVM__CORE__strtod(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (!obj_string) {
     SPVM_DIE("String must be defined", MFILE, __LINE__);
   }
-  const char* string = (const char*)env->belems(env, obj_string);
+  const char* string = (const char*)env->get_elems_byte(env, obj_string);
   
   char *end;
   errno = 0;
@@ -179,11 +179,11 @@ int32_t SPNATIVE__SPVM__CORE__memcpyb(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -219,11 +219,11 @@ int32_t SPNATIVE__SPVM__CORE__memmoveb(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -259,11 +259,11 @@ int32_t SPNATIVE__SPVM__CORE__memcpys(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -299,11 +299,11 @@ int32_t SPNATIVE__SPVM__CORE__memmoves(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -339,11 +339,11 @@ int32_t SPNATIVE__SPVM__CORE__memcpyi(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -379,11 +379,11 @@ int32_t SPNATIVE__SPVM__CORE__memmovei(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -419,11 +419,11 @@ int32_t SPNATIVE__SPVM__CORE__memcpyl(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -459,11 +459,11 @@ int32_t SPNATIVE__SPVM__CORE__memmovel(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -499,11 +499,11 @@ int32_t SPNATIVE__SPVM__CORE__memcpyf(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -539,11 +539,11 @@ int32_t SPNATIVE__SPVM__CORE__memmovef(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -579,11 +579,11 @@ int32_t SPNATIVE__SPVM__CORE__memcpyd(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -619,11 +619,11 @@ int32_t SPNATIVE__SPVM__CORE__memmoved(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Length must be zero or positive value", MFILE, __LINE__);
   }
   
-  char* dest_data = (char*)env->belems(env, obj_dest_data);
-  int32_t dest_data_len = env->len(env, obj_dest_data);
+  char* dest_data = (char*)env->get_elems_byte(env, obj_dest_data);
+  int32_t dest_data_len = env->length(env, obj_dest_data);
   
-  char* src_data = (char*)env->belems(env, obj_src_data);
-  int32_t src_data_len = env->len(env, obj_src_data);
+  char* src_data = (char*)env->get_elems_byte(env, obj_src_data);
+  int32_t src_data_len = env->length(env, obj_src_data);
   
   if (dest_offset + length > dest_data_len) {
     SPVM_DIE("Copy is over destination data", MFILE, __LINE__);
@@ -644,7 +644,7 @@ int32_t SPNATIVE__SPVM__CORE__getenv(SPVM_ENV* env, SPVM_VALUE* stack) {
   if (obj_name == NULL) {
     SPVM_DIE("Name must be defined", MFILE, __LINE__);
   }
-  const char* name = (const char*)env->belems(env, obj_name);
+  const char* name = (const char*)env->get_elems_byte(env, obj_name);
   
   const char* value = getenv(name);
   
@@ -653,7 +653,7 @@ int32_t SPNATIVE__SPVM__CORE__getenv(SPVM_ENV* env, SPVM_VALUE* stack) {
     obj_value = NULL;
   }
   else {
-    obj_value = env->new_str(env, value);
+    obj_value = env->new_string(env, value);
   }
   
   stack[0].oval = obj_value;
@@ -690,8 +690,8 @@ int32_t SPNATIVE__SPVM__CORE__new_oarray_proto(SPVM_ENV* env, SPVM_VALUE* stack)
     SPVM_DIE("Prototype array must be defined", MFILE, __LINE__);
   }
   
-  int32_t basic_type_id = env->object_basic_type_id(env, oarray);
-  int32_t element_dimension = env->object_type_dimension(env, oarray) - 1;
+  int32_t basic_type_id = env->get_object_basic_type_id(env, oarray);
+  int32_t element_dimension = env->get_object_type_dimension(env, oarray) - 1;
   
   void* new_oarray = env->new_marray(env, basic_type_id, element_dimension, length);
   
@@ -708,12 +708,12 @@ int32_t SPNATIVE__SPVM__CORE__reverseb(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Array must be defined", MFILE, __LINE__);
   }
 
-  int32_t array_length = env->len(env, onums);
+  int32_t array_length = env->length(env, onums);
   if (array_length == 0) {
     return SPVM_SUCCESS;
   }
   
-  int8_t* nums = env->belems(env, onums);
+  int8_t* nums = env->get_elems_byte(env, onums);
   
   for(int32_t i = 0; i < array_length / 2; i++){
     int8_t tmp = nums[i];
@@ -732,12 +732,12 @@ int32_t SPNATIVE__SPVM__CORE__reverses(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Array must be defined", MFILE, __LINE__);
   }
 
-  int32_t array_length = env->len(env, onums);
+  int32_t array_length = env->length(env, onums);
   if (array_length == 0) {
     return SPVM_SUCCESS;
   }
   
-  int16_t* nums = env->selems(env, onums);
+  int16_t* nums = env->get_elems_short(env, onums);
   
   for(int32_t i = 0; i < array_length / 2; i++){
     int16_t tmp = nums[i];
@@ -756,12 +756,12 @@ int32_t SPNATIVE__SPVM__CORE__reversei(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Array must be defined", MFILE, __LINE__);
   }
 
-  int32_t array_length = env->len(env, onums);
+  int32_t array_length = env->length(env, onums);
   if (array_length == 0) {
     return SPVM_SUCCESS;
   }
   
-  int32_t* nums = env->ielems(env, onums);
+  int32_t* nums = env->get_elems_int(env, onums);
   
   for(int32_t i = 0; i < array_length / 2; i++){
     int32_t tmp = nums[i];
@@ -780,12 +780,12 @@ int32_t SPNATIVE__SPVM__CORE__reversel(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Array must be defined", MFILE, __LINE__);
   }
 
-  int32_t array_length = env->len(env, onums);
+  int32_t array_length = env->length(env, onums);
   if (array_length == 0) {
     return SPVM_SUCCESS;
   }
   
-  int64_t* nums = env->lelems(env, onums);
+  int64_t* nums = env->get_elems_long(env, onums);
   
   for(int32_t i = 0; i < array_length / 2; i++){
     int64_t tmp = nums[i];
@@ -804,12 +804,12 @@ int32_t SPNATIVE__SPVM__CORE__reversef(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Array must be defined", MFILE, __LINE__);
   }
 
-  int32_t array_length = env->len(env, onums);
+  int32_t array_length = env->length(env, onums);
   if (array_length == 0) {
     return SPVM_SUCCESS;
   }
   
-  float* nums = env->felems(env, onums);
+  float* nums = env->get_elems_float(env, onums);
   
   for(int32_t i = 0; i < array_length / 2; i++){
     float tmp = nums[i];
@@ -828,12 +828,12 @@ int32_t SPNATIVE__SPVM__CORE__reversed(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Array must be defined", MFILE, __LINE__);
   }
 
-  int32_t array_length = env->len(env, onums);
+  int32_t array_length = env->length(env, onums);
   if (array_length == 0) {
     return SPVM_SUCCESS;
   }
   
-  double* nums = env->delems(env, onums);
+  double* nums = env->get_elems_double(env, onums);
   
   for(int32_t i = 0; i < array_length / 2; i++){
     double tmp = nums[i];
@@ -852,15 +852,15 @@ int32_t SPNATIVE__SPVM__CORE__reverseo(SPVM_ENV* env, SPVM_VALUE* stack) {
     SPVM_DIE("Array must be defined", MFILE, __LINE__);
   }
 
-  int32_t array_length = env->len(env, onums);
+  int32_t array_length = env->length(env, onums);
   if (array_length == 0) {
     return SPVM_SUCCESS;
   }
   
   for(int32_t i = 0; i < array_length / 2; i++){
-    void* tmp = env->oelem(env, onums, i);
-    env->set_oelem(env, onums, i, env->oelem(env, onums, array_length - i - 1));
-    env->set_oelem(env, onums, array_length - i - 1, tmp);
+    void* tmp = env->get_elem_object(env, onums, i);
+    env->set_elem_object(env, onums, i, env->get_elem_object(env, onums, array_length - i - 1));
+    env->set_elem_object(env, onums, array_length - i - 1, tmp);
   }
   
   return SPVM_SUCCESS;
@@ -873,7 +873,7 @@ int32_t SPNATIVE__SPVM__CORE__get_type_name(SPVM_ENV* env, SPVM_VALUE* stack) {
     return SPVM_EXCEPTION;
   }
   
-  void* type_name = env->type_name(env, object);
+  void* type_name = env->get_type_name(env, object);
   
   stack[0].oval = type_name;
   
@@ -885,8 +885,8 @@ int32_t SPNATIVE__SPVM__CORE__print(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* string = stack[0].oval;
   
-  const char* bytes = (const char*)env->belems(env, string);
-  int32_t string_length = env->len(env, string);
+  const char* bytes = (const char*)env->get_elems_byte(env, string);
+  int32_t string_length = env->length(env, string);
   
   {
     int32_t i;
@@ -898,26 +898,6 @@ int32_t SPNATIVE__SPVM__CORE__print(SPVM_ENV* env, SPVM_VALUE* stack) {
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__SPVM__CORE__warn(SPVM_ENV* env, SPVM_VALUE* stack) {
-  (void)env;
-  
-  void* object = stack[0].oval;
-  
-  const char* bytes = (const char*)env->belems(env, object);
-  int32_t string_length = env->len(env, object);
-  
-  {
-    int32_t i;
-    for (i = 0; i < string_length; i++) {
-      putc(bytes[i], stderr);
-    }
-  }
-  
-  fprintf(stderr, "\n");
-  
-  return SPVM_SUCCESS;
-}
-
 int32_t SPNATIVE__SPVM__CORE__FLT_MAX(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
