@@ -33,13 +33,10 @@ int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__new(SPVM_ENV* env, SPVM_VALUE* stac
   // Ignore SIGPIPE in unix like system
   signal(SIGPIPE, SIG_IGN);
 #endif
-  
-  // Ignore SIGPIPE
-  signal(SIGPIPE, SIG_IGN);
 
   // Dest string. Domain or IP address
   void* obj_deststr = stack[0].oval;
-  const char* deststr = (const char*)env->belems(env, obj_deststr);
+  const char* deststr = (const char*)env->get_elems_byte(env, obj_deststr);
   
   // Port
   int32_t port = stack[1].ival;
@@ -81,10 +78,10 @@ int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__new(SPVM_ENV* env, SPVM_VALUE* stac
   
   // Create SPVM::IO::ClientSocketTCP object
   void* obj_socket;
-  SPVM_NEW_OBJ(env, obj_socket, "SPVM::IO::ClientSocketTCP", MFILE, __LINE__);
+  SPVM_NEW_OBJECT(env, obj_socket, "SPVM::IO::ClientSocketTCP", MFILE, __LINE__);
   
   // Set handle
-  SPVM_SET_IFIELD(env, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", handle, MFILE, __LINE__);
+  SPVM_SET_FIELD_INT(env, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", handle, MFILE, __LINE__);
   
   stack[0].oval = obj_socket;
   
@@ -94,11 +91,11 @@ int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__new(SPVM_ENV* env, SPVM_VALUE* stac
 int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__read(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_socket = stack[0].oval;
   void* obj_buffer = stack[1].oval;
-  const char* buffer = (const char*)env->belems(env, obj_buffer);
-  int32_t length = env->len(env, obj_buffer);
+  const char* buffer = (const char*)env->get_elems_byte(env, obj_buffer);
+  int32_t length = env->length(env, obj_buffer);
   
   int32_t handle;
-  SPVM_IFIELD(env, handle, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
+  SPVM_GET_FIELD_INT(env, handle, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
 
   if (handle < 0) {
     SPVM_DIE("Handle is closed", MFILE, __LINE__);
@@ -118,11 +115,11 @@ int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__read(SPVM_ENV* env, SPVM_VALUE* sta
 int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__write(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_socket = stack[0].oval;
   void* obj_buffer = stack[1].oval;
-  const char* buffer = (const char*)env->belems(env, obj_buffer);
+  const char* buffer = (const char*)env->get_elems_byte(env, obj_buffer);
   int32_t length = stack[2].ival;
   
   int32_t handle;
-  SPVM_IFIELD(env, handle, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
+  SPVM_GET_FIELD_INT(env, handle, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
   
   if (handle < 0) {
     SPVM_DIE("Handle is closed", MFILE, __LINE__);
@@ -145,12 +142,12 @@ int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__close(SPVM_ENV* env, SPVM_VALUE* st
   void* obj_socket = stack[0].oval;
   
   int32_t handle;
-  SPVM_IFIELD(env, handle, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
+  SPVM_GET_FIELD_INT(env, handle, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
   
   if (handle >= 0) {
     int32_t ret = closesocket(handle);
     if (ret == 0) {
-      SPVM_SET_IFIELD(env, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", -1, MFILE, __LINE__);
+      SPVM_SET_FIELD_INT(env, obj_socket, "SPVM::IO::ClientSocketTCP", "handle", -1, MFILE, __LINE__);
     }
     else {
       SPVM_DIE("Fail close", MFILE, __LINE__);
@@ -167,7 +164,7 @@ int32_t SPNATIVE__SPVM__IO__ClientSocketTCP__fileno(SPVM_ENV* env, SPVM_VALUE* s
   
   // File fh
   int32_t handle;
-  SPVM_IFIELD(env, handle, obj_self, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
+  SPVM_GET_FIELD_INT(env, handle, obj_self, "SPVM::IO::ClientSocketTCP", "handle", MFILE, __LINE__);
   
   stack[0].ival = handle;
 
