@@ -1,3 +1,4 @@
+// Enable strerror_r, fileno
 #ifndef _XOPEN_SOURCE
 #  define _XOPEN_SOURCE 600
 #endif
@@ -12,6 +13,15 @@
 
 static const char* MFILE = "SPVM/IO/File.c";
 
+int32_t SPNATIVE__SPVM__IO__File__init_package_vars(SPVM_ENV* env, SPVM_VALUE* stack) {
+
+  SPVM_SET_PACKAGE_VAR_INT(env, "SPVM::IO::File", "$SEEK_SET", SEEK_SET, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_INT(env, "SPVM::IO::File", "$SEEK_CUR", SEEK_CUR, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_INT(env, "SPVM::IO::File", "$SEEK_END", SEEK_END, MFILE, __LINE__);
+  
+  return SPVM_SUCCESS;
+}
+
 int32_t SPNATIVE__SPVM__IO__File__fileno(SPVM_ENV* env, SPVM_VALUE* stack) {
   // Self
   void* obj_self = stack[0].oval;
@@ -19,8 +29,8 @@ int32_t SPNATIVE__SPVM__IO__File__fileno(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   // File fh
   void* obj_fh;
-  SPVM_OFIELD(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
-  FILE* fh = (FILE*)env->pointer(env, obj_fh);
+  SPVM_GET_FIELD_OBJECT(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
+  FILE* fh = (FILE*)env->get_pointer(env, obj_fh);
 
   if (fh == NULL) { SPVM_DIE("File handle must be defined", MFILE, __LINE__); }
   
@@ -38,8 +48,8 @@ int32_t SPNATIVE__SPVM__IO__File__readline(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   // File fh
   void* obj_fh;
-  SPVM_OFIELD(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
-  FILE* fh = (FILE*)env->pointer(env, obj_fh);
+  SPVM_GET_FIELD_OBJECT(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
+  FILE* fh = (FILE*)env->get_pointer(env, obj_fh);
 
   if (fh == NULL) {
     stack[0].oval = NULL;
@@ -50,7 +60,7 @@ int32_t SPNATIVE__SPVM__IO__File__readline(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   int32_t capacity = 80;
   void* obj_buffer = env->new_barray(env, capacity);
-  int8_t* buffer = env->belems(env, obj_buffer);
+  int8_t* buffer = env->get_elems_byte(env, obj_buffer);
   
   int32_t pos = 0;
   int32_t end_is_eof = 0;
@@ -64,15 +74,15 @@ int32_t SPNATIVE__SPVM__IO__File__readline(SPVM_ENV* env, SPVM_VALUE* stack) {
       if (pos >= capacity) {
         // Extend buffer capacity
         int32_t new_capacity = capacity * 2;
-        void* new_obj_buffer = env->new_barray(env, new_capacity);
-        int8_t* new_buffer = env->belems(env, new_obj_buffer);
+        void* new_object_buffer = env->new_barray(env, new_capacity);
+        int8_t* new_buffer = env->get_elems_byte(env, new_object_buffer);
         memcpy(new_buffer, buffer, capacity);
         
         int32_t removed = env->remove_mortal(env, scope_id, obj_buffer);
         assert(removed);
         
         capacity = new_capacity;
-        obj_buffer = new_obj_buffer;
+        obj_buffer = new_object_buffer;
         buffer = new_buffer;
       }
       
@@ -95,7 +105,7 @@ int32_t SPNATIVE__SPVM__IO__File__readline(SPVM_ENV* env, SPVM_VALUE* stack) {
     }
     else {
       oline = env->new_barray(env, pos);
-      int8_t* line = env->belems(env, oline);
+      int8_t* line = env->get_elems_byte(env, oline);
       memcpy(line, buffer, pos);
     }
     
@@ -116,8 +126,8 @@ int32_t SPNATIVE__SPVM__IO__File__seek(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   // File fh
   void* obj_fh;
-  SPVM_OFIELD(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
-  FILE* fh = (FILE*)env->pointer(env, obj_fh);
+  SPVM_GET_FIELD_OBJECT(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
+  FILE* fh = (FILE*)env->get_pointer(env, obj_fh);
   
   // Offset
   int64_t offset = stack[1].lval;
@@ -140,8 +150,8 @@ int32_t SPNATIVE__SPVM__IO__File__close(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   // File fh
   void* obj_fh;
-  SPVM_OFIELD(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
-  FILE* fh = (FILE*)env->pointer(env, obj_fh);
+  SPVM_GET_FIELD_OBJECT(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
+  FILE* fh = (FILE*)env->get_pointer(env, obj_fh);
   
   if (fh) {
     int32_t ret = fclose(fh);
@@ -165,8 +175,8 @@ int32_t SPNATIVE__SPVM__IO__File__read(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   // File fh
   void* obj_fh;
-  SPVM_OFIELD(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
-  FILE* fh = (FILE*)env->pointer(env, obj_fh);
+  SPVM_GET_FIELD_OBJECT(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
+  FILE* fh = (FILE*)env->get_pointer(env, obj_fh);
 
   // Buffer
   void* obj_buffer = stack[1].oval;
@@ -174,8 +184,8 @@ int32_t SPNATIVE__SPVM__IO__File__read(SPVM_ENV* env, SPVM_VALUE* stack) {
     stack[0].oval = NULL;
     return SPVM_SUCCESS;
   }
-  char* buffer = (char*)env->belems(env, obj_buffer);
-  int32_t buffer_length = env->len(env, obj_buffer);
+  char* buffer = (char*)env->get_elems_byte(env, obj_buffer);
+  int32_t buffer_length = env->length(env, obj_buffer);
   if (buffer_length == 0) {
     stack[0].ival = 0;
     return SPVM_SUCCESS;
@@ -196,8 +206,8 @@ int32_t SPNATIVE__SPVM__IO__File__write(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   // File fh
   void* obj_fh;
-  SPVM_OFIELD(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
-  FILE* fh = (FILE*)env->pointer(env, obj_fh);
+  SPVM_GET_FIELD_OBJECT(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
+  FILE* fh = (FILE*)env->get_pointer(env, obj_fh);
 
   int32_t length = stack[2].ival;
 
@@ -207,7 +217,7 @@ int32_t SPNATIVE__SPVM__IO__File__write(SPVM_ENV* env, SPVM_VALUE* stack) {
     stack[0].oval = NULL;
     return SPVM_SUCCESS;
   }
-  char* buffer = (char*)env->belems(env, obj_buffer);
+  char* buffer = (char*)env->get_elems_byte(env, obj_buffer);
   
   int32_t read_length = fwrite(buffer, 1, length, fh);
   
@@ -224,8 +234,8 @@ int32_t SPNATIVE__SPVM__IO__File__putc(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   // File fh
   void* obj_fh;
-  SPVM_OFIELD(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
-  FILE* fh = (FILE*)env->pointer(env, obj_fh);
+  SPVM_GET_FIELD_OBJECT(env, obj_fh, obj_self, "SPVM::IO::File", "fh", "SPVM::FileHandle", MFILE, __LINE__);
+  FILE* fh = (FILE*)env->get_pointer(env, obj_fh);
   
   // Char
   char ch = (char)stack[0].bval;
@@ -246,7 +256,7 @@ int32_t SPNATIVE__SPVM__IO__File__open(SPVM_ENV* env, SPVM_VALUE* stack) {
     stack[0].oval = NULL;
     return SPVM_SUCCESS;
   }
-  const char* file_name = (const char*)env->belems(env, obj_file_name);
+  const char* file_name = (const char*)env->get_elems_byte(env, obj_file_name);
   
   // Mode
   void* omode = stack[1].oval;
@@ -254,7 +264,7 @@ int32_t SPNATIVE__SPVM__IO__File__open(SPVM_ENV* env, SPVM_VALUE* stack) {
     stack[0].oval = NULL;
     return SPVM_SUCCESS;
   }
-  const char* mode = (const char*)env->belems(env, omode);
+  const char* mode = (const char*)env->get_elems_byte(env, omode);
   
   // Check mode
   int32_t valid_mode;
@@ -315,11 +325,11 @@ int32_t SPNATIVE__SPVM__IO__File__open(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   if (fh) {
     void* obj_io_file;
-    SPVM_NEW_OBJ(env, obj_io_file, "SPVM::IO::File", MFILE, __LINE__);
+    SPVM_NEW_OBJECT(env, obj_io_file, "SPVM::IO::File", MFILE, __LINE__);
 
     void* obj_fh;
     SPVM_NEW_POINTER(env, obj_fh, "SPVM::FileHandle", fh, MFILE, __LINE__);
-    SPVM_SET_OFIELD(env, obj_io_file, "SPVM::IO::File", "fh", "SPVM::FileHandle", obj_fh, MFILE, __LINE__);
+    SPVM_SET_FIELD_OBJECT(env, obj_io_file, "SPVM::IO::File", "fh", "SPVM::FileHandle", obj_fh, MFILE, __LINE__);
     
     stack[0].oval = obj_io_file;
   }
@@ -337,96 +347,6 @@ int32_t SPNATIVE__SPVM__IO__File__open(SPVM_ENV* env, SPVM_VALUE* stack) {
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__SPVM__IO__File__O_RDONLY(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef O_RDONLY
-  stack[0].ival = O_RDONLY;
-#else
-  SPVM_DIE("Errno O_RDONLY is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__O_WRONLY(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef O_WRONLY
-  stack[0].ival = O_WRONLY;
-#else
-  SPVM_DIE("Errno O_WRONLY is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__O_RDWR(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef O_RDWR
-  stack[0].ival = O_RDWR;
-#else
-  SPVM_DIE("Errno O_RDWR is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__O_APPEND(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef O_APPEND
-  stack[0].ival = O_APPEND;
-#else
-  SPVM_DIE("Errno O_APPEND is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__O_CREAT(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef O_CREAT
-  stack[0].ival = O_CREAT;
-#else
-  SPVM_DIE("Errno O_CREAT is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__O_TRUNC(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef O_TRUNC
-  stack[0].ival = O_TRUNC;
-#else
-  SPVM_DIE("Errno O_TRUNC is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__SEEK_SET(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef SEEK_SET
-  stack[0].ival = SEEK_SET;
-#else
-  SPVM_DIE("Errno SEEK_SET is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__SEEK_CUR(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef SEEK_CUR
-  stack[0].ival = SEEK_CUR;
-#else
-  SPVM_DIE("Errno SEEK_CUR is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
-int32_t SPNATIVE__SPVM__IO__File__SEEK_END(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef SEEK_END
-  stack[0].ival = SEEK_END;
-#else
-  SPVM_DIE("Errno SEEK_END is not defined", MFILE, __LINE__);
-#endif
-
-  return SPVM_SUCCESS;
-}
-
 int32_t SPNATIVE__SPVM__IO__File__EOF(SPVM_ENV* env, SPVM_VALUE* stack) {
 #ifdef EOF
   stack[0].ival = EOF;
@@ -458,7 +378,7 @@ int32_t SPNATIVE__SPVM__IO__File__STDOUT(SPVM_ENV* env, SPVM_VALUE* stack) {
 }
 
 int32_t SPNATIVE__SPVM__IO__File__STDERR(SPVM_ENV* env, SPVM_VALUE* stack) {
-#ifdef stdout
+#ifdef stderr
   stack[0].ival = fileno(stderr);
 #else
   SPVM_DIE("Errno STDERR is not defined", MFILE, __LINE__);
