@@ -7,151 +7,151 @@
 
 static const char* MFILE = "TestCase/Extension.c";
 
-int32_t SPNATIVE__TestCase__Extension__bpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__get_package_var_byte_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   int8_t value;
-  SPVM_BPKGVAR(env, value, "TestCase::Extension", "$BYTE_VALUE", MFILE, __LINE__);
+  SPVM_GET_PACKAGE_VAR_BYTE(env, value, "TestCase::Extension", "$BYTE_VALUE", MFILE, __LINE__);
   
   stack[0].bval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__spkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__get_package_var_short_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   int16_t value;
-  SPVM_SPKGVAR(env, value,  "TestCase::Extension", "$SHORT_VALUE", MFILE, __LINE__);
+  SPVM_GET_PACKAGE_VAR_SHORT(env, value,  "TestCase::Extension", "$SHORT_VALUE", MFILE, __LINE__);
   
   stack[0].sval = value;
 
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__ipkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__get_package_var_int_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   int32_t value;
-  SPVM_IPKGVAR(env, value, "TestCase::Extension", "$INT_VALUE", MFILE, __LINE__);
+  SPVM_GET_PACKAGE_VAR_INT(env, value, "TestCase::Extension", "$INT_VALUE", MFILE, __LINE__);
   
   stack[0].ival = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__lpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__get_package_var_long_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   int64_t value;
-  SPVM_LPKGVAR(env, value, "TestCase::Extension", "$LONG_VALUE", MFILE, __LINE__);
+  SPVM_GET_PACKAGE_VAR_LONG(env, value, "TestCase::Extension", "$LONG_VALUE", MFILE, __LINE__);
   
   stack[0].lval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__fpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__get_package_var_float_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   float value;
-  SPVM_FPKGVAR(env, value, "TestCase::Extension", "$FLOAT_VALUE", MFILE, __LINE__);
+  SPVM_GET_PACKAGE_VAR_FLOAT(env, value, "TestCase::Extension", "$FLOAT_VALUE", MFILE, __LINE__);
   
   stack[0].fval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__dpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__get_package_var_double_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   double value;
-  SPVM_DPKGVAR(env, value, "TestCase::Extension", "$DOUBLE_VALUE", MFILE, __LINE__);
+  SPVM_GET_PACKAGE_VAR_DOUBLE(env, value, "TestCase::Extension", "$DOUBLE_VALUE", MFILE, __LINE__);
   
   stack[0].dval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__opkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__get_package_var_object_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* value;
-  SPVM_OPKGVAR(env, value, "TestCase::Extension", "$MINIMAL_VALUE", "TestCase::Minimal", MFILE, __LINE__);
+  SPVM_GET_PACKAGE_VAR_OBJECT(env, value, "TestCase::Extension", "$MINIMAL_VALUE", "TestCase::Minimal", MFILE, __LINE__);
   
   stack[0].oval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__set_bpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__set_package_var_byte_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
-  SPVM_SET_BPKGVAR(env, "TestCase::Extension", "$BYTE_VALUE", INT8_MIN, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_BYTE(env, "TestCase::Extension", "$BYTE_VALUE", INT8_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__set_spkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__set_package_var_short_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
-  SPVM_SET_SPKGVAR(env, "TestCase::Extension", "$SHORT_VALUE", INT16_MIN, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_SHORT(env, "TestCase::Extension", "$SHORT_VALUE", INT16_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__set_ipkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__set_package_var_int_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
-  SPVM_SET_IPKGVAR(env, "TestCase::Extension", "$INT_VALUE", INT32_MIN, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_INT(env, "TestCase::Extension", "$INT_VALUE", INT32_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__set_lpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__set_package_var_long_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
-  SPVM_SET_LPKGVAR(env, "TestCase::Extension", "$LONG_VALUE", INT64_MIN, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_LONG(env, "TestCase::Extension", "$LONG_VALUE", INT64_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__set_fpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__set_package_var_float_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
-  SPVM_SET_FPKGVAR(env, "TestCase::Extension", "$FLOAT_VALUE", FLT_MIN, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_FLOAT(env, "TestCase::Extension", "$FLOAT_VALUE", FLT_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__set_dpkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__set_package_var_double_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
-  SPVM_SET_DPKGVAR(env, "TestCase::Extension", "$DOUBLE_VALUE", DBL_MIN, MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_DOUBLE(env, "TestCase::Extension", "$DOUBLE_VALUE", DBL_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__set_opkgvar_test(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__set_package_var_object_test(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* minimal;
-  SPVM_NEW_OBJ(env, minimal, "TestCase::Minimal", MFILE, __LINE__);
-  SPVM_SET_OPKGVAR(env, "TestCase::Extension", "$MINIMAL_VALUE", "TestCase::Minimal", minimal, MFILE, __LINE__);
+  SPVM_NEW_OBJECT(env, minimal, "TestCase::Minimal", MFILE, __LINE__);
+  SPVM_SET_PACKAGE_VAR_OBJECT(env, "TestCase::Extension", "$MINIMAL_VALUE", "TestCase::Minimal", minimal, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
@@ -163,7 +163,7 @@ int32_t SPNATIVE__TestCase__Extension__has_callback_test(SPVM_ENV* env, SPVM_VAL
   
   void* object = stack[0].oval;
   
-  int32_t basic_type_id = env->basic_type_id(env, "TestCase::Callback::Callback");
+  int32_t basic_type_id = env->get_basic_type_id(env, "TestCase::Callback::Callback");
   if (basic_type_id < 0) {
     assert(0);
   }
@@ -181,7 +181,7 @@ int32_t SPNATIVE__TestCase__Extension__is_type_test_minimals(SPVM_ENV* env, SPVM
   
   void* object = stack[0].oval;
   
-  int32_t basic_type_id = env->basic_type_id(env, "TestCase::Minimal");
+  int32_t basic_type_id = env->get_basic_type_id(env, "TestCase::Minimal");
   if (basic_type_id < 0) {
     assert(0);
   }
@@ -265,108 +265,108 @@ int32_t SPNATIVE__TestCase__Extension__ref_double_sum(SPVM_ENV* env, SPVM_VALUE*
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_set_bfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_set_field_byte(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
-  SPVM_SET_BFIELD(env, object, "TestCase::Simple", "byte_value", INT8_MIN, MFILE, __LINE__);
+  SPVM_SET_FIELD_BYTE(env, object, "TestCase::Simple", "byte_value", INT8_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_set_sfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_set_field_short(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
-  SPVM_SET_SFIELD(env, object, "TestCase::Simple", "short_value", INT16_MIN, MFILE, __LINE__);
+  SPVM_SET_FIELD_SHORT(env, object, "TestCase::Simple", "short_value", INT16_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_set_ifield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_set_field_int(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
-  SPVM_SET_IFIELD(env, object, "TestCase::Simple", "int_value", INT32_MIN, MFILE, __LINE__);
+  SPVM_SET_FIELD_INT(env, object, "TestCase::Simple", "int_value", INT32_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_set_lfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_set_field_long(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
-  SPVM_SET_LFIELD(env, object, "TestCase::Simple", "long_value", INT64_MIN, MFILE, __LINE__);
+  SPVM_SET_FIELD_LONG(env, object, "TestCase::Simple", "long_value", INT64_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_set_ffield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_set_field_float(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
-  SPVM_SET_FFIELD(env, object, "TestCase::Simple", "float_value", FLT_MIN, MFILE, __LINE__);
+  SPVM_SET_FIELD_FLOAT(env, object, "TestCase::Simple", "float_value", FLT_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_set_dfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_set_field_double(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
-  SPVM_SET_DFIELD(env, object, "TestCase::Simple", "double_value", DBL_MIN, MFILE, __LINE__);
+  SPVM_SET_FIELD_DOUBLE(env, object, "TestCase::Simple", "double_value", DBL_MIN, MFILE, __LINE__);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_set_ofield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_set_field_object(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* object_simple = stack[0].oval;
   
-  int32_t field_id_object_simple_object_value = env->field_id(env, "TestCase::Simple", "object_value", "TestCase::Minimal");
+  int32_t field_id_object_simple_object_value = env->get_field_id(env, "TestCase::Simple", "object_value", "TestCase::Minimal");
   if (field_id_object_simple_object_value < 0) {
     return SPVM_EXCEPTION;
   }
   
-  int32_t basic_type_id = env->basic_type_id(env, "TestCase::Minimal");
+  int32_t basic_type_id = env->get_basic_type_id(env, "TestCase::Minimal");
   if (basic_type_id < 0) {
     return SPVM_EXCEPTION;
   }
-  void* object_minimal = env->new_obj(env, basic_type_id);
+  void* object_minimal = env->new_object(env, basic_type_id);
   
-  int32_t field_id_minimal_x = env->field_id(env, "TestCase::Minimal", "x", "int");
+  int32_t field_id_minimal_x = env->get_field_id(env, "TestCase::Minimal", "x", "int");
   if (field_id_minimal_x < 0) {
     return SPVM_EXCEPTION;
   }
-  env->set_ifield(env, object_minimal, field_id_minimal_x, 3);
+  env->set_field_int(env, object_minimal, field_id_minimal_x, 3);
   
-  env->set_ofield(env, object_simple, field_id_object_simple_object_value, object_minimal);
+  env->set_field_object(env, object_simple, field_id_object_simple_object_value, object_minimal);
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_get_bfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_get_get_field_byte(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
   SPVM_VALUE_byte byte_value;
-  SPVM_BFIELD(env, byte_value, object, "TestCase::Simple", "byte_value", MFILE, __LINE__);
+  SPVM_GET_FIELD_BYTE(env, byte_value, object, "TestCase::Simple", "byte_value", MFILE, __LINE__);
   
   if (byte_value == INT8_MIN) {
     stack[0].ival = 1;
@@ -378,14 +378,14 @@ int32_t SPNATIVE__TestCase__Extension__native_get_bfield(SPVM_ENV* env, SPVM_VAL
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_get_sfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_get_get_field_short(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
   SPVM_VALUE_short short_value;
-  SPVM_SFIELD(env, short_value, object, "TestCase::Simple", "short_value", MFILE, __LINE__);
+  SPVM_GET_FIELD_SHORT(env, short_value, object, "TestCase::Simple", "short_value", MFILE, __LINE__);
   
   if (short_value == INT16_MIN) {
     stack[0].ival = 1;
@@ -397,14 +397,14 @@ int32_t SPNATIVE__TestCase__Extension__native_get_sfield(SPVM_ENV* env, SPVM_VAL
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_get_ifield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_get_get_field_int(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
   SPVM_VALUE_int int_value;
-  SPVM_IFIELD(env, int_value, object, "TestCase::Simple", "int_value", MFILE, __LINE__);
+  SPVM_GET_FIELD_INT(env, int_value, object, "TestCase::Simple", "int_value", MFILE, __LINE__);
   
   if (int_value == INT32_MIN) {
     stack[0].ival = 1;
@@ -416,14 +416,14 @@ int32_t SPNATIVE__TestCase__Extension__native_get_ifield(SPVM_ENV* env, SPVM_VAL
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_get_lfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_get_get_field_long(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
   SPVM_VALUE_long long_value;
-  SPVM_LFIELD(env, long_value, object, "TestCase::Simple", "long_value", MFILE, __LINE__);
+  SPVM_GET_FIELD_LONG(env, long_value, object, "TestCase::Simple", "long_value", MFILE, __LINE__);
   
   if (long_value == INT64_MIN) {
     stack[0].ival = 1;
@@ -435,14 +435,14 @@ int32_t SPNATIVE__TestCase__Extension__native_get_lfield(SPVM_ENV* env, SPVM_VAL
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_get_ffield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_get_get_field_float(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
   SPVM_VALUE_float float_value;
-  SPVM_FFIELD(env, float_value, object, "TestCase::Simple", "float_value", MFILE, __LINE__);
+  SPVM_GET_FIELD_FLOAT(env, float_value, object, "TestCase::Simple", "float_value", MFILE, __LINE__);
   
   if (float_value == FLT_MIN) {
     stack[0].ival = 1;
@@ -454,14 +454,14 @@ int32_t SPNATIVE__TestCase__Extension__native_get_ffield(SPVM_ENV* env, SPVM_VAL
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_get_dfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_get_get_field_double(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
 
   void* object = stack[0].oval;
   
   SPVM_VALUE_double double_value;
-  SPVM_DFIELD(env, double_value, object, "TestCase::Simple", "double_value", MFILE, __LINE__);
+  SPVM_GET_FIELD_DOUBLE(env, double_value, object, "TestCase::Simple", "double_value", MFILE, __LINE__);
   
   if (double_value == DBL_MIN) {
     stack[0].ival = 1;
@@ -473,25 +473,25 @@ int32_t SPNATIVE__TestCase__Extension__native_get_dfield(SPVM_ENV* env, SPVM_VAL
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_get_ofield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_get_get_field_object(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* object_simple = stack[0].oval;
   
-  int32_t field_id_object_simple_object_value = env->field_id(env, "TestCase::Simple", "object_value", "TestCase::Minimal");
+  int32_t field_id_object_simple_object_value = env->get_field_id(env, "TestCase::Simple", "object_value", "TestCase::Minimal");
   if (field_id_object_simple_object_value < 0) {
     return SPVM_EXCEPTION;
   }
   
-  void* object_minimal = env->ofield(env, object_simple, field_id_object_simple_object_value);
+  void* object_minimal = env->get_field_object(env, object_simple, field_id_object_simple_object_value);
   
-  int32_t field_id_minimal_x = env->field_id(env, "TestCase::Minimal", "x", "int");
+  int32_t field_id_minimal_x = env->get_field_id(env, "TestCase::Minimal", "x", "int");
   if (field_id_minimal_x < 0) {
     return SPVM_EXCEPTION;
   }
   
-  int32_t x = env->ifield(env, object_minimal, field_id_minimal_x);
+  int32_t x = env->get_field_int(env, object_minimal, field_id_minimal_x);
   
   if (x == 5) {
     stack[0].ival = 1;
@@ -509,7 +509,7 @@ int32_t SPNATIVE__TestCase__Extension__native_use_strlen(SPVM_ENV* env, SPVM_VAL
   
   void* string = stack[0].oval;
   
-  int8_t* bytes = env->belems(env, string);
+  int8_t* bytes = env->get_elems_byte(env, string);
   
   int32_t length = (int32_t)strlen((char*)bytes);
   
@@ -518,126 +518,126 @@ int32_t SPNATIVE__TestCase__Extension__native_use_strlen(SPVM_ENV* env, SPVM_VAL
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_env_bfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_env_get_field_byte(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* test_case = stack[0].oval;
   
-  int32_t field_id = env->field_id(env, test_case, "x_byte", "byte");
+  int32_t field_id = env->get_field_id(env, test_case, "x_byte", "byte");
   if (field_id < 0) {
     return SPVM_EXCEPTION;
   }
   
-  int8_t value = env->bfield(env, test_case, field_id);
+  int8_t value = env->get_field_byte(env, test_case, field_id);
   
   stack[0].bval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_env_sfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_env_get_field_short(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* test_case = stack[0].oval;
   
-  int32_t field_id = env->field_id(env, test_case, "x_short", "short");
+  int32_t field_id = env->get_field_id(env, test_case, "x_short", "short");
   if (field_id < 0) {
     return SPVM_EXCEPTION;
   }
   
-  int16_t value = env->sfield(env, test_case, field_id);
+  int16_t value = env->get_field_short(env, test_case, field_id);
   
   stack[0].sval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_env_ifield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_env_get_field_int(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* test_case = stack[0].oval;
   
-  int32_t field_id = env->field_id(env, test_case, "x_int", "int");
+  int32_t field_id = env->get_field_id(env, test_case, "x_int", "int");
   if (field_id < 0) {
     return SPVM_EXCEPTION;
   }
   
-  int32_t value = env->ifield(env, test_case, field_id);
+  int32_t value = env->get_field_int(env, test_case, field_id);
   
   stack[0].ival = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_env_lfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_env_get_field_long(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* test_case = stack[0].oval;
   
-  int32_t field_id = env->field_id(env, test_case, "x_long", "long");
+  int32_t field_id = env->get_field_id(env, test_case, "x_long", "long");
   if (field_id < 0) {
     return SPVM_EXCEPTION;
   }
   
-  int64_t value = env->lfield(env, test_case, field_id);
+  int64_t value = env->get_field_long(env, test_case, field_id);
   
   stack[0].ival = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_env_ffield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_env_get_field_float(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* test_case = stack[0].oval;
   
-  int32_t field_id = env->field_id(env, test_case, "x_float", "float");
+  int32_t field_id = env->get_field_id(env, test_case, "x_float", "float");
   if (field_id < 0) {
     return SPVM_EXCEPTION;
   }
   
-  float value = env->ffield(env, test_case, field_id);
+  float value = env->get_field_float(env, test_case, field_id);
   
   stack[0].fval = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_env_dfield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_env_get_field_double(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* test_case = stack[0].oval;
   
-  int32_t field_id = env->field_id(env, test_case, "x_double", "double");
+  int32_t field_id = env->get_field_id(env, test_case, "x_double", "double");
   if (field_id < 0) {
     return SPVM_EXCEPTION;
   }
   
-  double value = env->dfield(env, test_case, field_id);
+  double value = env->get_field_double(env, test_case, field_id);
   
   stack[0].ival = value;
   
   return SPVM_SUCCESS;
 }
 
-int32_t SPNATIVE__TestCase__Extension__native_env_ofield(SPVM_ENV* env, SPVM_VALUE* stack) {
+int32_t SPNATIVE__TestCase__Extension__native_env_get_field_object(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)env;
   (void)stack;
   
   void* test_case = stack[0].oval;
   
-  int32_t field_id = env->field_id(env, test_case, "minimal", "TestCase::Minimal");
+  int32_t field_id = env->get_field_id(env, test_case, "minimal", "TestCase::Minimal");
   if (field_id < 0) {
     return SPVM_EXCEPTION;
   }
   
-  void* value = env->ofield(env, test_case, field_id);
+  void* value = env->get_field_object(env, test_case, field_id);
   
   stack[0].oval = value;
   
@@ -663,13 +663,13 @@ int32_t SPNATIVE__TestCase__Extension__add_iarray(SPVM_ENV* env, SPVM_VALUE* sta
   void* obj_nums1 = stack[0].oval;
   void* obj_nums2 = stack[1].oval;
   
-  int32_t length = env->len(env, obj_nums1);
+  int32_t length = env->length(env, obj_nums1);
   
-  int32_t* nums1 = env->ielems(env, obj_nums1);
-  int32_t* nums2 = env->ielems(env, obj_nums2);
+  int32_t* nums1 = env->get_elems_int(env, obj_nums1);
+  int32_t* nums2 = env->get_elems_int(env, obj_nums2);
   
   void* onums3 = env->new_iarray(env, length);
-  int32_t* nums3 = env->ielems(env, onums3);
+  int32_t* nums3 = env->get_elems_int(env, onums3);
   
   for (int32_t i = 0; i < length; i++) {
     nums3[i] = nums1[i] + nums2[i];
@@ -747,73 +747,73 @@ int32_t SPNATIVE__TestCase__Extension__mortal_api(SPVM_ENV* env, SPVM_VALUE* sta
   // 1
   {
     void* sp_values = env->new_barray(env, length);
-    ref_count += env->ref_count(env, sp_values);
+    ref_count += env->get_ref_count(env, sp_values);
   }
   // 2
   {
     void* sp_values = env->new_sarray(env, length);
-    ref_count += env->ref_count(env, sp_values);
+    ref_count += env->get_ref_count(env, sp_values);
   }
   // 3
   {
     void* sp_values = env->new_iarray(env, length);
-    ref_count += env->ref_count(env, sp_values);
+    ref_count += env->get_ref_count(env, sp_values);
   }
   // 4
   {
     void* sp_values = env->new_larray(env, length);
-    ref_count += env->ref_count(env, sp_values);
+    ref_count += env->get_ref_count(env, sp_values);
   }
   // 5
   {
     void* sp_values = env->new_farray(env, length);
-    ref_count += env->ref_count(env, sp_values);
+    ref_count += env->get_ref_count(env, sp_values);
   }
   // 6
   {
     void* sp_values = env->new_larray(env, length);
-    ref_count += env->ref_count(env, sp_values);
+    ref_count += env->get_ref_count(env, sp_values);
   }
   // 7
   {
-    void* sp_values = env->new_str(env, "foo");
-    ref_count += env->ref_count(env, sp_values);
+    void* sp_values = env->new_string(env, "foo");
+    ref_count += env->get_ref_count(env, sp_values);
   }
   // 8
   {
-    int32_t basic_type_id = env->basic_type_id(env, "TestCase::Minimal");
+    int32_t basic_type_id = env->get_basic_type_id(env, "TestCase::Minimal");
     if (basic_type_id < 0) {
       return SPVM_EXCEPTION;
     }
-    void* sp_object = env->new_obj(env, basic_type_id);
-    ref_count += env->ref_count(env, sp_object);
+    void* sp_object = env->new_object(env, basic_type_id);
+    ref_count += env->get_ref_count(env, sp_object);
   }
   // 9
   {
-    int32_t basic_type_id = env->basic_type_id(env, "TestCase::Minimal");
+    int32_t basic_type_id = env->get_basic_type_id(env, "TestCase::Minimal");
     if (basic_type_id < 0) {
       return SPVM_EXCEPTION;
     }
     void* sp_objects = env->new_oarray(env, basic_type_id, 3);
-    ref_count += env->ref_count(env, sp_objects);
+    ref_count += env->get_ref_count(env, sp_objects);
   }
   // 10
   {
-    int32_t basic_type_id = env->basic_type_id(env, "TestCase::Minimal");
+    int32_t basic_type_id = env->get_basic_type_id(env, "TestCase::Minimal");
     if (basic_type_id < 0) {
       return SPVM_EXCEPTION;
     }
     void* sp_objects = env->new_oarray(env, basic_type_id, 3);
-    ref_count += env->ref_count(env, sp_objects);
+    ref_count += env->get_ref_count(env, sp_objects);
   }
   // 11
   {
-    int32_t basic_type_id = env->basic_type_id(env, "TestCase::Pointer");
+    int32_t basic_type_id = env->get_basic_type_id(env, "TestCase::Pointer");
     if (basic_type_id < 0) {
       return SPVM_EXCEPTION;
     }
     void* sp_objects = env->new_pointer(env, basic_type_id, NULL);
-    ref_count += env->ref_count(env, sp_objects);
+    ref_count += env->get_ref_count(env, sp_objects);
   }
   
   if (ref_count == 11) {
@@ -831,10 +831,10 @@ int32_t SPNATIVE__TestCase__Extension__enter_scope_leave_scope(SPVM_ENV* env, SP
   (void)stack;
   
   int32_t length = 10;
-  int32_t start_memory_blocks_count = env->memory_blocks_count(env);
+  int32_t start_memory_blocks_count = env->get_memory_blocks_count(env);
   env->new_iarray(env, length);
   env->new_iarray(env, length);
-  int32_t before_enter_memory_blocks_count = env->memory_blocks_count(env);
+  int32_t before_enter_memory_blocks_count = env->get_memory_blocks_count(env);
   int32_t before_leave_memory_blocks_count;
   {
     int32_t scope_id = env->enter_scope(env);
@@ -843,11 +843,11 @@ int32_t SPNATIVE__TestCase__Extension__enter_scope_leave_scope(SPVM_ENV* env, SP
     env->new_iarray(env, length);
     env->new_iarray(env, length);
     
-    before_leave_memory_blocks_count = env->memory_blocks_count(env);
+    before_leave_memory_blocks_count = env->get_memory_blocks_count(env);
     env->leave_scope(env, scope_id);
   }
   
-  int32_t after_leave_memory_blocks_counts = env->memory_blocks_count(env);
+  int32_t after_leave_memory_blocks_counts = env->get_memory_blocks_count(env);
   
   stack[0].ival = 0;
   if ((before_enter_memory_blocks_count - start_memory_blocks_count) == 2) {
@@ -865,7 +865,7 @@ int32_t SPNATIVE__TestCase__Extension__native_call_sub(SPVM_ENV* env, SPVM_VALUE
   (void)env;
   (void)stack;
   
-  int32_t sub_id = env->sub_id(env, "TestCase::Extension", "my_value", "int(int)");
+  int32_t sub_id = env->get_sub_id(env, "TestCase::Extension", "my_value", "int(int)");
   if (sub_id < 0) {
     return SPVM_EXCEPTION;
   }
